@@ -348,6 +348,7 @@ int edg_wll_SetParamTime(edg_wll_Context ctx,edg_wll_ContextParam param,const st
 int edg_wll_SetParam(edg_wll_Context ctx,edg_wll_ContextParam param,...)
 {
 	va_list	ap;
+	int ret;
 
 	va_start(ap,param);
 	switch (param) {
@@ -360,7 +361,8 @@ int edg_wll_SetParam(edg_wll_Context ctx,edg_wll_ContextParam param,...)
 		case EDG_WLL_PARAM_QUERY_RESULTS:
 		case EDG_WLL_PARAM_CONNPOOL_SIZE:
 		case EDG_WLL_PARAM_SOURCE:           
-			return edg_wll_SetParamInt(ctx,param,va_arg(ap,int));
+			ret = edg_wll_SetParamInt(ctx,param,va_arg(ap,int));
+			break;
 		case EDG_WLL_PARAM_HOST:             
 		case EDG_WLL_PARAM_INSTANCE:         
 		case EDG_WLL_PARAM_DESTINATION:      
@@ -377,13 +379,59 @@ int edg_wll_SetParam(edg_wll_Context ctx,edg_wll_ContextParam param,...)
 	        case EDG_WLL_PARAM_LOG_FILE_PREFIX:
 	        case EDG_WLL_PARAM_LOG_IL_SOCK:
 		case EDG_WLL_PARAM_LBPROXY_SERVERNAME:
-			return edg_wll_SetParamString(ctx,param,va_arg(ap,char *));
+			ret = edg_wll_SetParamString(ctx,param,va_arg(ap,char *));
+			break;
 		case EDG_WLL_PARAM_LOG_TIMEOUT:      
 		case EDG_WLL_PARAM_LOG_SYNC_TIMEOUT: 
 		case EDG_WLL_PARAM_QUERY_TIMEOUT:    
 		case EDG_WLL_PARAM_NOTIF_TIMEOUT:    
-			return edg_wll_SetParamTime(ctx,param,va_arg(ap,struct timeval *));
+			ret = edg_wll_SetParamTime(ctx,param,va_arg(ap,struct timeval *));
+			break;
 		default: 
+			ret = edg_wll_SetError(ctx,EINVAL,"unknown parameter");
+			break;
+	}
+	va_end(ap);
+
+	return ret;
+}
+
+int edg_wll_SetParamToDefault(edg_wll_Context ctx,edg_wll_ContextParam param)
+{
+	switch (param) {
+		case EDG_WLL_PARAM_LEVEL:
+		case EDG_WLL_PARAM_DESTINATION_PORT:
+		case EDG_WLL_PARAM_QUERY_SERVER_PORT:
+		case EDG_WLL_PARAM_NOTIF_SERVER_PORT:
+		case EDG_WLL_PARAM_QUERY_JOBS_LIMIT:
+		case EDG_WLL_PARAM_QUERY_EVENTS_LIMIT:
+		case EDG_WLL_PARAM_QUERY_RESULTS:
+		case EDG_WLL_PARAM_CONNPOOL_SIZE:
+		case EDG_WLL_PARAM_SOURCE:
+			return edg_wll_SetParamInt(ctx,param,0);
+		case EDG_WLL_PARAM_HOST:
+		case EDG_WLL_PARAM_INSTANCE:
+		case EDG_WLL_PARAM_DESTINATION:
+		case EDG_WLL_PARAM_QUERY_SERVER:
+		case EDG_WLL_PARAM_NOTIF_SERVER:
+		case EDG_WLL_PARAM_QUERY_SERVER_OVERRIDE:
+		case EDG_WLL_PARAM_X509_PROXY:
+		case EDG_WLL_PARAM_X509_KEY:
+		case EDG_WLL_PARAM_X509_CERT:
+		case EDG_WLL_PARAM_LBPROXY_STORE_SOCK:
+		case EDG_WLL_PARAM_LBPROXY_SERVE_SOCK:
+		case EDG_WLL_PARAM_LBPROXY_USER:
+		case EDG_WLL_PARAM_JPREG_TMPDIR:
+	        case EDG_WLL_PARAM_LOG_FILE_PREFIX:
+	        case EDG_WLL_PARAM_LOG_IL_SOCK:
+		case EDG_WLL_PARAM_LBPROXY_SERVERNAME:
+			return edg_wll_SetParamString(ctx,param,NULL);
+		case EDG_WLL_PARAM_LOG_TIMEOUT:
+		case EDG_WLL_PARAM_LOG_SYNC_TIMEOUT:
+		case EDG_WLL_PARAM_QUERY_TIMEOUT:
+		case EDG_WLL_PARAM_NOTIF_TIMEOUT:
+			return edg_wll_SetParamTime(ctx,param,NULL);
+		default:
 			return edg_wll_SetError(ctx,EINVAL,"unknown parameter");
 	}
 }
@@ -522,6 +570,7 @@ int edg_wll_GetParam(edg_wll_Context ctx,edg_wll_ContextParam param,...)
 			break;
 			
 		default: 
+			va_end(ap);
 			return edg_wll_SetError(ctx, EINVAL, "unknown parameter");
 			break;
 	}
